@@ -14,7 +14,8 @@
 
 import logging
 
-from webull.trade.events.types import ORDER_STATUS_CHANGED, EVENT_TYPE_ORDER
+from webull.trade.events.types import ORDER_STATUS_CHANGED, EVENT_TYPE_ORDER, EVENT_TYPE_POSITION, \
+    POSITION_STATUS_CHANGED
 from webull.trade.trade_events_client import TradeEventsClient
 
 your_app_key = "<your_app_key>"
@@ -32,12 +33,16 @@ def my_on_events_message(event_type, subscribe_type, payload, raw_message):
     if EVENT_TYPE_ORDER == event_type and ORDER_STATUS_CHANGED == subscribe_type:
         print('----request_id:%s----' % payload['request_id'])
         print(payload)
+    if EVENT_TYPE_POSITION == event_type and POSITION_STATUS_CHANGED == subscribe_type:
+        print('event payload:%s' % payload)
 
 if __name__ == '__main__':
 
     # Create EventsClient instance
     trade_events_client = TradeEventsClient(your_app_key, your_app_secret, region_id)
-    # For non production environment, you need to set the domain name of the subscription service through eventsclient. For example, the domain name of the UAT environment is set here
+    # [Important] For non production environment, you need to set the domain name of the subscription service through events client. For example, the domain name of the UAT environment is set here
+    # [Important] For non production environment, you need to set the domain name of the subscription service through events client. For example, the domain name of the UAT environment is set here
+    # [Important] For non production environment, you need to set the domain name of the subscription service through events client. For example, the domain name of the UAT environment is set here
     # trade_events_client = TradeEventsClient(your_app_key, your_app_secret, region_id, host=optional_api_endpoint)
     trade_events_client.on_log = _on_log
 
